//
//  AdTimingBid.h
//  AdTimingBid SDK
//
//  Copyright 2017 AdTimingBid Inc. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import "AdTimingBidAdType.h"


NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, AdTimingBidGender) {
    AdTimingBidGenderUnknown,
    AdTimingBidGenderMale,
    AdTimingBidGenderFemale,
};

typedef NS_ENUM(NSInteger, AdTimingBidConsentStatus) {
    AdTimingBidConsentStatusUnknown,
    AdTimingBidConsentStatusDenied,
    AdTimingBidConsentStatusConsented,
};

typedef void(^initCompletionHandler)(NSError *_Nullable error);


@interface AdTimingBid : NSObject

/// Initializes AdTimingBid's SDK with all the ad types that are defined in the platform.
+ (void)initWithAppKey:(NSString*)appKey;

/// Check that `AdTimingBid` has been initialized
+ (BOOL)isInitialized;

/// current SDK version
+ (NSString *)SDKVersion;

/// setUserConsent "NO" is Refuse，"YES" is Accepted. //GDPR
/// According to the GDPR, set method of this property must be called before "initWithAppKey:", or by default will collect user's information.
+ (void)setGDPRConsent:(BOOL)consent;

/// Gives the current consent status of this user.
+ (AdTimingBidConsentStatus)currentConsentStatus;

///According to the CCPA, set method of this property must be called before "initWithAppKey:", or by default will collect user's information.
+ (void)setUSPrivacyLimit:(BOOL)privacyLimit;

/// log enable,default is YES
+ (void)setLogEnable:(BOOL)logEnable;

/// Set this property to configure the user's age.
+ (void)setUserAge:(NSInteger)userAge;

/// Set the gender of the current user
+ (void)setUserGender:(AdTimingBidGender)userGender;

/// Set custom user id
+ (void)setUserID:(NSString*)userID;

///bidderToken
+ (NSString*)bidderToken;

@end

NS_ASSUME_NONNULL_END
